# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.db_user_client_role import DbUserClientRole
from neurograph.v1.models.db_user_org_role import DbUserOrgRole
from neurograph.v1.models.db_user_role import DbUserRole
from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp
from typing import Optional, Set
from typing_extensions import Self

class DbUserInDb(BaseModel):
    """
    DbUserInDb
    """ # noqa: E501
    client_roles: Optional[List[DbUserClientRole]] = None
    display_name: Optional[StrictStr] = None
    email: Optional[StrictStr] = None
    firebase_uid: Optional[StrictStr] = None
    id: Optional[StrictInt] = None
    org_roles: Optional[List[DbUserOrgRole]] = None
    roles: Optional[List[DbUserRole]] = None
    ts_created: Optional[PgtypeTimestamp] = None
    ts_updated: Optional[PgtypeTimestamp] = None
    __properties: ClassVar[List[str]] = ["client_roles", "display_name", "email", "firebase_uid", "id", "org_roles", "roles", "ts_created", "ts_updated"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DbUserInDb from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in client_roles (list)
        _items = []
        if self.client_roles:
            for _item_client_roles in self.client_roles:
                if _item_client_roles:
                    _items.append(_item_client_roles.to_dict())
            _dict['client_roles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in org_roles (list)
        _items = []
        if self.org_roles:
            for _item_org_roles in self.org_roles:
                if _item_org_roles:
                    _items.append(_item_org_roles.to_dict())
            _dict['org_roles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in roles (list)
        _items = []
        if self.roles:
            for _item_roles in self.roles:
                if _item_roles:
                    _items.append(_item_roles.to_dict())
            _dict['roles'] = _items
        # override the default output from pydantic by calling `to_dict()` of ts_created
        if self.ts_created:
            _dict['ts_created'] = self.ts_created.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ts_updated
        if self.ts_updated:
            _dict['ts_updated'] = self.ts_updated.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DbUserInDb from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "client_roles": [DbUserClientRole.from_dict(_item) for _item in obj["client_roles"]] if obj.get("client_roles") is not None else None,
            "display_name": obj.get("display_name"),
            "email": obj.get("email"),
            "firebase_uid": obj.get("firebase_uid"),
            "id": obj.get("id"),
            "org_roles": [DbUserOrgRole.from_dict(_item) for _item in obj["org_roles"]] if obj.get("org_roles") is not None else None,
            "roles": [DbUserRole.from_dict(_item) for _item in obj["roles"]] if obj.get("roles") is not None else None,
            "ts_created": PgtypeTimestamp.from_dict(obj["ts_created"]) if obj.get("ts_created") is not None else None,
            "ts_updated": PgtypeTimestamp.from_dict(obj["ts_updated"]) if obj.get("ts_updated") is not None else None
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from neurograph.v1.models.admin_permission_response import AdminPermissionResponse
from neurograph.v1.models.admin_set_permission_request import AdminSetPermissionRequest
from neurograph.v1.models.admin_upsert_user_request import AdminUpsertUserRequest
from neurograph.v1.models.admin_upsert_user_response import AdminUpsertUserResponse
from neurograph.v1.models.admin_user import AdminUser
from neurograph.v1.models.admin_user_detail_response import AdminUserDetailResponse
from neurograph.v1.models.admin_users_get_many_response import AdminUsersGetManyResponse
from neurograph.v1.models.admin_users_org_response import AdminUsersOrgResponse
from neurograph.v1.models.auth_service_token_request import AuthServiceTokenRequest
from neurograph.v1.models.auth_service_token_response import AuthServiceTokenResponse
from neurograph.v1.models.auth_test_service_token_request import AuthTestServiceTokenRequest
from neurograph.v1.models.auth_test_service_token_response import AuthTestServiceTokenResponse
from neurograph.v1.models.auth_test_token_response import AuthTestTokenResponse
from neurograph.v1.models.client_client import ClientClient
from neurograph.v1.models.client_delete_metadata_request import ClientDeleteMetadataRequest
from neurograph.v1.models.client_get_detail_response import ClientGetDetailResponse
from neurograph.v1.models.client_get_many_response import ClientGetManyResponse
from neurograph.v1.models.client_info import ClientInfo
from neurograph.v1.models.client_kpi import ClientKpi
from neurograph.v1.models.client_match_criteria_row_in_db import ClientMatchCriteriaRowInDb
from neurograph.v1.models.client_metadata import ClientMetadata
from neurograph.v1.models.client_metadata_request import ClientMetadataRequest
from neurograph.v1.models.client_metadata_response import ClientMetadataResponse
from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand
from neurograph.v1.models.client_organization_detail import ClientOrganizationDetail
from neurograph.v1.models.client_persona import ClientPersona
from neurograph.v1.models.client_persona_factor import ClientPersonaFactor
from neurograph.v1.models.client_persona_insight import ClientPersonaInsight
from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait
from neurograph.v1.models.client_personas_response import ClientPersonasResponse
from neurograph.v1.models.client_probe import ClientProbe
from neurograph.v1.models.client_probe_todo_row import ClientProbeTodoRow
from neurograph.v1.models.client_query import ClientQuery
from neurograph.v1.models.client_trigger_probe_response import ClientTriggerProbeResponse
from neurograph.v1.models.client_url_snapshot_response import ClientURLSnapshotResponse
from neurograph.v1.models.client_upsert_request import ClientUpsertRequest
from neurograph.v1.models.client_upsert_response import ClientUpsertResponse
from neurograph.v1.models.client_url_row import ClientUrlRow
from neurograph.v1.models.client_url_snapshot_row import ClientUrlSnapshotRow
from neurograph.v1.models.client_url_upsert_request import ClientUrlUpsertRequest
from neurograph.v1.models.client_url_upsert_response import ClientUrlUpsertResponse
from neurograph.v1.models.client_urls_response import ClientUrlsResponse
from neurograph.v1.models.client_workbench_config import ClientWorkbenchConfig
from neurograph.v1.models.dagster_info import DagsterInfo
from neurograph.v1.models.dagster_log_create_request import DagsterLogCreateRequest
from neurograph.v1.models.dagster_log_create_response import DagsterLogCreateResponse
from neurograph.v1.models.dagster_log_get_response import DagsterLogGetResponse
from neurograph.v1.models.db_account_organization_brand import DbAccountOrganizationBrand
from neurograph.v1.models.db_client_url import DbClientUrl
from neurograph.v1.models.db_knowledge_customer import DbKnowledgeCustomer
from neurograph.v1.models.db_knowledge_order import DbKnowledgeOrder
from neurograph.v1.models.db_knowledge_product import DbKnowledgeProduct
from neurograph.v1.models.db_knowledge_store import DbKnowledgeStore
from neurograph.v1.models.db_my_client import DbMyClient
from neurograph.v1.models.db_my_org import DbMyOrg
from neurograph.v1.models.db_persona_factor_create_params import DbPersonaFactorCreateParams
from neurograph.v1.models.db_user_client_role import DbUserClientRole
from neurograph.v1.models.db_user_in_db import DbUserInDb
from neurograph.v1.models.db_user_org_role import DbUserOrgRole
from neurograph.v1.models.db_user_role import DbUserRole
from neurograph.v1.models.knowledge_assertion import KnowledgeAssertion
from neurograph.v1.models.knowledge_assertion_create_request import KnowledgeAssertionCreateRequest
from neurograph.v1.models.knowledge_assertion_list_response import KnowledgeAssertionListResponse
from neurograph.v1.models.knowledge_assertion_query import KnowledgeAssertionQuery
from neurograph.v1.models.knowledge_assertion_response import KnowledgeAssertionResponse
from neurograph.v1.models.knowledge_customer_query import KnowledgeCustomerQuery
from neurograph.v1.models.knowledge_customer_response import KnowledgeCustomerResponse
from neurograph.v1.models.knowledge_enrichment_artifact import KnowledgeEnrichmentArtifact
from neurograph.v1.models.knowledge_enrichment_artifact_create_request import KnowledgeEnrichmentArtifactCreateRequest
from neurograph.v1.models.knowledge_enrichment_artifact_list_response import KnowledgeEnrichmentArtifactListResponse
from neurograph.v1.models.knowledge_enrichment_artifact_response import KnowledgeEnrichmentArtifactResponse
from neurograph.v1.models.knowledge_enrichment_artifact_update_output_request import KnowledgeEnrichmentArtifactUpdateOutputRequest
from neurograph.v1.models.knowledge_enrichment_artifact_update_status_request import KnowledgeEnrichmentArtifactUpdateStatusRequest
from neurograph.v1.models.knowledge_enrichment_query import KnowledgeEnrichmentQuery
from neurograph.v1.models.knowledge_entity import KnowledgeEntity
from neurograph.v1.models.knowledge_entity_create_request import KnowledgeEntityCreateRequest
from neurograph.v1.models.knowledge_entity_create_response import KnowledgeEntityCreateResponse
from neurograph.v1.models.knowledge_entity_err_row import KnowledgeEntityErrRow
from neurograph.v1.models.knowledge_entity_extra import KnowledgeEntityExtra
from neurograph.v1.models.knowledge_entity_get_many_response import KnowledgeEntityGetManyResponse
from neurograph.v1.models.knowledge_entity_in_db import KnowledgeEntityInDb
from neurograph.v1.models.knowledge_entity_relations import KnowledgeEntityRelations
from neurograph.v1.models.knowledge_entity_schema import KnowledgeEntitySchema
from neurograph.v1.models.knowledge_entity_schema_row import KnowledgeEntitySchemaRow
from neurograph.v1.models.knowledge_entity_schema_upsert_request import KnowledgeEntitySchemaUpsertRequest
from neurograph.v1.models.knowledge_entity_schemas_response import KnowledgeEntitySchemasResponse
from neurograph.v1.models.knowledge_entity_schemas_upsert_response import KnowledgeEntitySchemasUpsertResponse
from neurograph.v1.models.knowledge_entity_type_response import KnowledgeEntityTypeResponse
from neurograph.v1.models.knowledge_entity_type_row import KnowledgeEntityTypeRow
from neurograph.v1.models.knowledge_entity_type_upsert_request import KnowledgeEntityTypeUpsertRequest
from neurograph.v1.models.knowledge_entity_type_upsert_row import KnowledgeEntityTypeUpsertRow
from neurograph.v1.models.knowledge_entity_upsert_request import KnowledgeEntityUpsertRequest
from neurograph.v1.models.knowledge_entity_upsert_response import KnowledgeEntityUpsertResponse
from neurograph.v1.models.knowledge_ingest_raw_request import KnowledgeIngestRawRequest
from neurograph.v1.models.knowledge_ingest_raw_response import KnowledgeIngestRawResponse
from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow
from neurograph.v1.models.knowledge_kind_response import KnowledgeKindResponse
from neurograph.v1.models.knowledge_order_query import KnowledgeOrderQuery
from neurograph.v1.models.knowledge_order_response import KnowledgeOrderResponse
from neurograph.v1.models.knowledge_product import KnowledgeProduct
from neurograph.v1.models.knowledge_product_query import KnowledgeProductQuery
from neurograph.v1.models.knowledge_product_response import KnowledgeProductResponse
from neurograph.v1.models.knowledge_product_upsert_request import KnowledgeProductUpsertRequest
from neurograph.v1.models.knowledge_product_upsert_response import KnowledgeProductUpsertResponse
from neurograph.v1.models.knowledge_query import KnowledgeQuery
from neurograph.v1.models.knowledge_store_query import KnowledgeStoreQuery
from neurograph.v1.models.knowledge_store_response import KnowledgeStoreResponse
from neurograph.v1.models.lookup_env import LookupEnv
from neurograph.v1.models.lookup_language import LookupLanguage
from neurograph.v1.models.lookup_language_response import LookupLanguageResponse
from neurograph.v1.models.lookup_lookup_environments_response import LookupLookupEnvironmentsResponse
from neurograph.v1.models.lookup_role import LookupRole
from neurograph.v1.models.lookup_roles_response import LookupRolesResponse
from neurograph.v1.models.lookup_state import LookupState
from neurograph.v1.models.lookup_state_response import LookupStateResponse
from neurograph.v1.models.lookup_states_response import LookupStatesResponse
from neurograph.v1.models.lookup_uid import LookupUid
from neurograph.v1.models.lookup_uids_response import LookupUidsResponse
from neurograph.v1.models.me_my_profile_response import MeMyProfileResponse
from neurograph.v1.models.organizations_brand import OrganizationsBrand
from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse
from neurograph.v1.models.organizations_brand_upsert_request import OrganizationsBrandUpsertRequest
from neurograph.v1.models.organizations_create_request import OrganizationsCreateRequest
from neurograph.v1.models.organizations_delete_metadata_request import OrganizationsDeleteMetadataRequest
from neurograph.v1.models.organizations_delete_metadata_response import OrganizationsDeleteMetadataResponse
from neurograph.v1.models.organizations_detail_response import OrganizationsDetailResponse
from neurograph.v1.models.organizations_get_many_response import OrganizationsGetManyResponse
from neurograph.v1.models.organizations_metadata import OrganizationsMetadata
from neurograph.v1.models.organizations_metadata_request import OrganizationsMetadataRequest
from neurograph.v1.models.organizations_metadata_response import OrganizationsMetadataResponse
from neurograph.v1.models.organizations_organization import OrganizationsOrganization
from neurograph.v1.models.organizations_organization_set_workbench_request import OrganizationsOrganizationSetWorkbenchRequest
from neurograph.v1.models.organizations_organization_set_workbench_response import OrganizationsOrganizationSetWorkbenchResponse
from neurograph.v1.models.organizations_organization_update_request import OrganizationsOrganizationUpdateRequest
from neurograph.v1.models.organizations_workbench_config import OrganizationsWorkbenchConfig
from neurograph.v1.models.personas_factor_create_request import PersonasFactorCreateRequest
from neurograph.v1.models.personas_factor_create_response import PersonasFactorCreateResponse
from neurograph.v1.models.personas_factor_row import PersonasFactorRow
from neurograph.v1.models.personas_insight_create_request import PersonasInsightCreateRequest
from neurograph.v1.models.personas_insight_create_response import PersonasInsightCreateResponse
from neurograph.v1.models.personas_instance_create_request import PersonasInstanceCreateRequest
from neurograph.v1.models.personas_instance_create_response import PersonasInstanceCreateResponse
from neurograph.v1.models.personas_instance_delete_many_request import PersonasInstanceDeleteManyRequest
from neurograph.v1.models.personas_instance_delete_many_response import PersonasInstanceDeleteManyResponse
from neurograph.v1.models.personas_instances_response import PersonasInstancesResponse
from neurograph.v1.models.personas_kpi import PersonasKpi
from neurograph.v1.models.personas_kpi_create_request import PersonasKpiCreateRequest
from neurograph.v1.models.personas_kpi_create_response import PersonasKpiCreateResponse
from neurograph.v1.models.personas_kpi_req_row import PersonasKpiReqRow
from neurograph.v1.models.personas_kpi_row_in_db import PersonasKpiRowInDb
from neurograph.v1.models.personas_match_criteria_request import PersonasMatchCriteriaRequest
from neurograph.v1.models.personas_match_criteria_response import PersonasMatchCriteriaResponse
from neurograph.v1.models.personas_match_criteria_row_in import PersonasMatchCriteriaRowIn
from neurograph.v1.models.personas_match_criteria_row_in_db import PersonasMatchCriteriaRowInDb
from neurograph.v1.models.personas_persona import PersonasPersona
from neurograph.v1.models.personas_persona_factor import PersonasPersonaFactor
from neurograph.v1.models.personas_persona_insight import PersonasPersonaInsight
from neurograph.v1.models.personas_persona_personality_trait import PersonasPersonaPersonalityTrait
from neurograph.v1.models.personas_personality_trait_create_request import PersonasPersonalityTraitCreateRequest
from neurograph.v1.models.personas_personality_trait_create_response import PersonasPersonalityTraitCreateResponse
from neurograph.v1.models.personas_personality_trait_in_db import PersonasPersonalityTraitInDb
from neurograph.v1.models.personas_personality_trait_req import PersonasPersonalityTraitReq
from neurograph.v1.models.personas_seed import PersonasSeed
from neurograph.v1.models.personas_seed_get_many_response import PersonasSeedGetManyResponse
from neurograph.v1.models.personas_seed_upsert_request import PersonasSeedUpsertRequest
from neurograph.v1.models.personas_seeds_delete_response import PersonasSeedsDeleteResponse
from neurograph.v1.models.pgtype_infinity_modifier import PgtypeInfinityModifier
from neurograph.v1.models.pgtype_int8 import PgtypeInt8
from neurograph.v1.models.pgtype_text import PgtypeText
from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp
from neurograph.v1.models.reporting_daily_metric import ReportingDailyMetric
from neurograph.v1.models.reporting_daily_metrics_response import ReportingDailyMetricsResponse
from neurograph.v1.models.reporting_query import ReportingQuery
from neurograph.v1.models.workbench_workbench_url_check_request import WorkbenchWorkbenchUrlCheckRequest
from neurograph.v1.models.workbench_workbench_url_check_response import WorkbenchWorkbenchUrlCheckResponse
from neurograph.v1.models.workbench_workbench_version import WorkbenchWorkbenchVersion
from neurograph.v1.models.workbench_workbench_version_many_response import WorkbenchWorkbenchVersionManyResponse
from neurograph.v1.models.workbench_workbench_version_response import WorkbenchWorkbenchVersionResponse
from neurograph.v1.models.workbench_workbench_version_upsert_request import WorkbenchWorkbenchVersionUpsertRequest




# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.personas_instances_response import PersonasInstancesResponse

class TestPersonasInstancesResponse(unittest.TestCase):
    """PersonasInstancesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PersonasInstancesResponse:
        """Test PersonasInstancesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PersonasInstancesResponse`
        """
        model = PersonasInstancesResponse()
        if include_optional:
            return PersonasInstancesResponse(
                data = [
                    neurograph.v1.models.personas/persona.personas.Persona(
                        age = 1.337, 
                        description = '', 
                        factors = [
                            neurograph.v1.models.personas/persona_factor.personas.PersonaFactor(
                                detail = '', 
                                display = '', 
                                id = 56, 
                                name = '', 
                                persona_instance_id = '', 
                                summary = '', 
                                value = 56, )
                            ], 
                        female = 1.337, 
                        id = '', 
                        income = '', 
                        insights = [
                            neurograph.v1.models.personas/persona_insight.personas.PersonaInsight(
                                data = neurograph.v1.models.data.data(), 
                                id = 56, 
                                key = '', 
                                persona_instance_id = 56, )
                            ], 
                        kpis = [
                            neurograph.v1.models.personas/kpi.personas.Kpi(
                                id = 56, 
                                name = '', 
                                persona_instance_id = '', 
                                value = '', )
                            ], 
                        male = 1.337, 
                        match_criteria = [
                            neurograph.v1.models.personas/match_criteria_row_in_db.personas.MatchCriteriaRowInDb(
                                concept = '', 
                                detail = '', 
                                display = '', 
                                error = '', 
                                id = 56, 
                                persona_instance_id = '', )
                            ], 
                        metadata = '', 
                        name = '', 
                        persona_seed_id = '', 
                        personality_background = '', 
                        personality_first_name = '', 
                        personality_img_url = '', 
                        personality_last_name = '', 
                        personality_quote = '', 
                        personality_traits = [
                            neurograph.v1.models.personas/persona_personality_trait.personas.PersonaPersonalityTrait(
                                id = 56, 
                                name = '', 
                                persona_instance_id = '', 
                                traits = [
                                    ''
                                    ], )
                            ], 
                        personality_video_url = '', 
                        positioning_statement = '', 
                        seed_uid = '', 
                        summary_detail = '', 
                        summary_headline = '', 
                        tag = '', 
                        ts_created = 56, 
                        ts_updated = 56, 
                        value = '', )
                    ],
                error = '',
                query_limit = 56,
                query_offset = 56,
                total_rows = 56
            )
        else:
            return PersonasInstancesResponse(
        )
        """

    def testPersonasInstancesResponse(self):
        """Test PersonasInstancesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.persona_api import PersonaApi


class TestPersonaApi(unittest.TestCase):
    """PersonaApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PersonaApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_persona_factors_post(self) -> None:
        """Test case for api_v1_persona_factors_post

        Create Persona Factors
        """
        pass

    def test_api_v1_persona_insight_post(self) -> None:
        """Test case for api_v1_persona_insight_post

        Create a Persona Insight
        """
        pass

    def test_api_v1_persona_instance_delete(self) -> None:
        """Test case for api_v1_persona_instance_delete

        Delete one or more Persona Instances and associated data
        """
        pass

    def test_api_v1_persona_instance_get(self) -> None:
        """Test case for api_v1_persona_instance_get

        Get Persona Instances and all associated data
        """
        pass

    def test_api_v1_persona_instance_post(self) -> None:
        """Test case for api_v1_persona_instance_post

        Create a Persona Instance
        """
        pass

    def test_api_v1_persona_kpi_post(self) -> None:
        """Test case for api_v1_persona_kpi_post

        Create Persona KPIs
        """
        pass

    def test_api_v1_persona_match_criteria_post(self) -> None:
        """Test case for api_v1_persona_match_criteria_post

        Create Persona Match Criteria
        """
        pass

    def test_api_v1_persona_personality_trait_post(self) -> None:
        """Test case for api_v1_persona_personality_trait_post

        Create a Persona Traits
        """
        pass

    def test_api_v1_persona_seed_get(self) -> None:
        """Test case for api_v1_persona_seed_get

        Get one or more Persona Seeds
        """
        pass

    def test_api_v1_persona_seed_post(self) -> None:
        """Test case for api_v1_persona_seed_post

        Upsert a Persona Seed
        """
        pass

    def test_api_v1_persona_seed_seed_id_delete(self) -> None:
        """Test case for api_v1_persona_seed_seed_id_delete

        Delete a persona seed
        """
        pass

    def test_api_v1_persona_seed_seed_id_status_put(self) -> None:
        """Test case for api_v1_persona_seed_seed_id_status_put

        Toggle a Persona Seed
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from neurograph.v1.models.admin_users_org_response import AdminUsersOrgResponse
from neurograph.v1.models.client_get_detail_response import ClientGetDetailResponse
from neurograph.v1.models.client_get_many_response import ClientGetManyResponse
from neurograph.v1.models.client_personas_response import ClientPersonasResponse
from neurograph.v1.models.client_trigger_probe_response import ClientTriggerProbeResponse
from neurograph.v1.models.client_url_snapshot_response import ClientURLSnapshotResponse
from neurograph.v1.models.client_upsert_request import ClientUpsertRequest
from neurograph.v1.models.client_upsert_response import ClientUpsertResponse
from neurograph.v1.models.client_url_upsert_request import ClientUrlUpsertRequest
from neurograph.v1.models.client_url_upsert_response import ClientUrlUpsertResponse
from neurograph.v1.models.client_urls_response import ClientUrlsResponse

from neurograph.v1.api_client import ApiClient, RequestSerialized
from neurograph.v1.api_response import ApiResponse
from neurograph.v1.rest import RESTResponseType


class ClientApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v1_client_personas_client_id_get(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ClientPersonasResponse:
        """Get Client's Personas

        Get all Client Personas

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_personas_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientPersonasResponse",
            '400': "ClientPersonasResponse",
            '503': "ClientPersonasResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_client_personas_client_id_get_with_http_info(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ClientPersonasResponse]:
        """Get Client's Personas

        Get all Client Personas

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_personas_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientPersonasResponse",
            '400': "ClientPersonasResponse",
            '503': "ClientPersonasResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_client_personas_client_id_get_without_preload_content(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Client's Personas

        Get all Client Personas

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_personas_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientPersonasResponse",
            '400': "ClientPersonasResponse",
            '503': "ClientPersonasResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_client_personas_client_id_get_serialize(
        self,
        client_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if client_id is not None:
            _path_params['client_id'] = client_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/client/personas/{client_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_client_url_client_id_get(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ClientUrlsResponse:
        """Get client's URLs

        Returns all of the client's urls for the given client id

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientUrlsResponse",
            '400': "ClientUrlsResponse",
            '503': "ClientUrlsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_client_url_client_id_get_with_http_info(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ClientUrlsResponse]:
        """Get client's URLs

        Returns all of the client's urls for the given client id

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientUrlsResponse",
            '400': "ClientUrlsResponse",
            '503': "ClientUrlsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_client_url_client_id_get_without_preload_content(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get client's URLs

        Returns all of the client's urls for the given client id

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientUrlsResponse",
            '400': "ClientUrlsResponse",
            '503': "ClientUrlsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_client_url_client_id_get_serialize(
        self,
        client_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if client_id is not None:
            _path_params['client_id'] = client_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/client/url/{client_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_client_url_post(
        self,
        request: Annotated[ClientUrlUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ClientUrlUpsertResponse:
        """Upsert a Client Url

        Inserts a Client Url into the db when the `id` is \"\".  Updates when the `id` is not an empty string.

        :param request: Body (required)
        :type request: ClientUrlUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientUrlUpsertResponse",
            '400': "ClientUrlUpsertResponse",
            '503': "ClientUrlUpsertResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_client_url_post_with_http_info(
        self,
        request: Annotated[ClientUrlUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ClientUrlUpsertResponse]:
        """Upsert a Client Url

        Inserts a Client Url into the db when the `id` is \"\".  Updates when the `id` is not an empty string.

        :param request: Body (required)
        :type request: ClientUrlUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientUrlUpsertResponse",
            '400': "ClientUrlUpsertResponse",
            '503': "ClientUrlUpsertResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_client_url_post_without_preload_content(
        self,
        request: Annotated[ClientUrlUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upsert a Client Url

        Inserts a Client Url into the db when the `id` is \"\".  Updates when the `id` is not an empty string.

        :param request: Body (required)
        :type request: ClientUrlUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientUrlUpsertResponse",
            '400': "ClientUrlUpsertResponse",
            '503': "ClientUrlUpsertResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_client_url_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/client/url/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_client_url_probe_client_id_post(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ClientTriggerProbeResponse:
        """Trigger client URL probes

        Triggers probes for the client's URLs.

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_probe_client_id_post_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientTriggerProbeResponse",
            '400': "ClientTriggerProbeResponse",
            '503': "ClientTriggerProbeResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_client_url_probe_client_id_post_with_http_info(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ClientTriggerProbeResponse]:
        """Trigger client URL probes

        Triggers probes for the client's URLs.

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_probe_client_id_post_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientTriggerProbeResponse",
            '400': "ClientTriggerProbeResponse",
            '503': "ClientTriggerProbeResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_client_url_probe_client_id_post_without_preload_content(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Trigger client URL probes

        Triggers probes for the client's URLs.

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_probe_client_id_post_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientTriggerProbeResponse",
            '400': "ClientTriggerProbeResponse",
            '503': "ClientTriggerProbeResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_client_url_probe_client_id_post_serialize(
        self,
        client_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if client_id is not None:
            _path_params['client_id'] = client_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/client/url-probe/{client_id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_client_url_snapshot_probe_id_get(
        self,
        probe_id: Annotated[StrictStr, Field(description="Probe ID (clp_*)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ClientURLSnapshotResponse:
        """Get a client's URL snapshot by probe id

        Returns the HTML snapshot and related metadata for the given client_id and probe_id

        :param probe_id: Probe ID (clp_*) (required)
        :type probe_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_snapshot_probe_id_get_serialize(
            probe_id=probe_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientURLSnapshotResponse",
            '400': "ClientURLSnapshotResponse",
            '404': "ClientURLSnapshotResponse",
            '503': "ClientURLSnapshotResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_client_url_snapshot_probe_id_get_with_http_info(
        self,
        probe_id: Annotated[StrictStr, Field(description="Probe ID (clp_*)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ClientURLSnapshotResponse]:
        """Get a client's URL snapshot by probe id

        Returns the HTML snapshot and related metadata for the given client_id and probe_id

        :param probe_id: Probe ID (clp_*) (required)
        :type probe_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_snapshot_probe_id_get_serialize(
            probe_id=probe_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientURLSnapshotResponse",
            '400': "ClientURLSnapshotResponse",
            '404': "ClientURLSnapshotResponse",
            '503': "ClientURLSnapshotResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_client_url_snapshot_probe_id_get_without_preload_content(
        self,
        probe_id: Annotated[StrictStr, Field(description="Probe ID (clp_*)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a client's URL snapshot by probe id

        Returns the HTML snapshot and related metadata for the given client_id and probe_id

        :param probe_id: Probe ID (clp_*) (required)
        :type probe_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_client_url_snapshot_probe_id_get_serialize(
            probe_id=probe_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientURLSnapshotResponse",
            '400': "ClientURLSnapshotResponse",
            '404': "ClientURLSnapshotResponse",
            '503': "ClientURLSnapshotResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_client_url_snapshot_probe_id_get_serialize(
        self,
        probe_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if probe_id is not None:
            _path_params['probe_id'] = probe_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/client/url-snapshot/{probe_id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_clients_client_id_get(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ClientGetDetailResponse:
        """Get Client by ID

        Get all Client details by their ID

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientGetDetailResponse",
            '400': "ClientGetDetailResponse",
            '503': "ClientGetDetailResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_clients_client_id_get_with_http_info(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ClientGetDetailResponse]:
        """Get Client by ID

        Get all Client details by their ID

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientGetDetailResponse",
            '400': "ClientGetDetailResponse",
            '503': "ClientGetDetailResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_clients_client_id_get_without_preload_content(
        self,
        client_id: Annotated[StrictStr, Field(description="Client's ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Client by ID

        Get all Client details by their ID

        :param client_id: Client's ID (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientGetDetailResponse",
            '400': "ClientGetDetailResponse",
            '503': "ClientGetDetailResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_clients_client_id_get_serialize(
        self,
        client_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if client_id is not None:
            _path_params['client_id'] = client_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/clients/{client_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_clients_client_id_users_get(
        self,
        client_id: Annotated[StrictStr, Field(description="Client ID (cli_*)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AdminUsersOrgResponse:
        """Client's assigned users and their permissions


        :param client_id: Client ID (cli_*) (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_client_id_users_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminUsersOrgResponse",
            '503': "AdminUsersOrgResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_clients_client_id_users_get_with_http_info(
        self,
        client_id: Annotated[StrictStr, Field(description="Client ID (cli_*)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AdminUsersOrgResponse]:
        """Client's assigned users and their permissions


        :param client_id: Client ID (cli_*) (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_client_id_users_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminUsersOrgResponse",
            '503': "AdminUsersOrgResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_clients_client_id_users_get_without_preload_content(
        self,
        client_id: Annotated[StrictStr, Field(description="Client ID (cli_*)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Client's assigned users and their permissions


        :param client_id: Client ID (cli_*) (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_client_id_users_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminUsersOrgResponse",
            '503': "AdminUsersOrgResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_clients_client_id_users_get_serialize(
        self,
        client_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if client_id is not None:
            _path_params['client_id'] = client_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/clients/{client_id}/users/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_clients_get(
        self,
        org_id: Annotated[Optional[StrictStr], Field(description="filter by the Organization's ID")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of records")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Record offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ClientGetManyResponse:
        """Get Clients

        Get all Clients. Optionally filter for Organization Guid (orgGuid) or Organization Account OrgId (AccountId).

        :param org_id: filter by the Organization's ID
        :type org_id: str
        :param limit: Maximum number of records
        :type limit: int
        :param offset: Record offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_get_serialize(
            org_id=org_id,
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientGetManyResponse",
            '400': "ClientGetManyResponse",
            '503': "ClientGetManyResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_clients_get_with_http_info(
        self,
        org_id: Annotated[Optional[StrictStr], Field(description="filter by the Organization's ID")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of records")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Record offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ClientGetManyResponse]:
        """Get Clients

        Get all Clients. Optionally filter for Organization Guid (orgGuid) or Organization Account OrgId (AccountId).

        :param org_id: filter by the Organization's ID
        :type org_id: str
        :param limit: Maximum number of records
        :type limit: int
        :param offset: Record offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_get_serialize(
            org_id=org_id,
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientGetManyResponse",
            '400': "ClientGetManyResponse",
            '503': "ClientGetManyResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_clients_get_without_preload_content(
        self,
        org_id: Annotated[Optional[StrictStr], Field(description="filter by the Organization's ID")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of records")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Record offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Clients

        Get all Clients. Optionally filter for Organization Guid (orgGuid) or Organization Account OrgId (AccountId).

        :param org_id: filter by the Organization's ID
        :type org_id: str
        :param limit: Maximum number of records
        :type limit: int
        :param offset: Record offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_get_serialize(
            org_id=org_id,
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientGetManyResponse",
            '400': "ClientGetManyResponse",
            '503': "ClientGetManyResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_clients_get_serialize(
        self,
        org_id,
        limit,
        offset,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if org_id is not None:
            
            _query_params.append(('orgId', org_id))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/clients/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_clients_post(
        self,
        request: Annotated[ClientUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ClientUpsertResponse:
        """Upsert a Client

        Inserts a Client into the db when the `id` is \"\".  Updates when the `id` is not an empty string.

        :param request: Body (required)
        :type request: ClientUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientUpsertResponse",
            '400': "ClientUpsertResponse",
            '503': "ClientUpsertResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_clients_post_with_http_info(
        self,
        request: Annotated[ClientUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ClientUpsertResponse]:
        """Upsert a Client

        Inserts a Client into the db when the `id` is \"\".  Updates when the `id` is not an empty string.

        :param request: Body (required)
        :type request: ClientUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientUpsertResponse",
            '400': "ClientUpsertResponse",
            '503': "ClientUpsertResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_clients_post_without_preload_content(
        self,
        request: Annotated[ClientUpsertRequest, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upsert a Client

        Inserts a Client into the db when the `id` is \"\".  Updates when the `id` is not an empty string.

        :param request: Body (required)
        :type request: ClientUpsertRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_clients_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientUpsertResponse",
            '400': "ClientUpsertResponse",
            '503': "ClientUpsertResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_clients_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/clients/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_daily_metrics_response import ReportingDailyMetricsResponse

class TestReportingDailyMetricsResponse(unittest.TestCase):
    """ReportingDailyMetricsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingDailyMetricsResponse:
        """Test ReportingDailyMetricsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingDailyMetricsResponse`
        """
        model = ReportingDailyMetricsResponse()
        if include_optional:
            return ReportingDailyMetricsResponse(
                data = [
                    neurograph.v1.models.reporting/daily_metric.reporting.DailyMetric(
                        avg_lifetime_value = 1.337, 
                        avg_ltv_original = 1.337, 
                        customers_with_orders = 56, 
                        data_quality_flag = '', 
                        iqr_avg_ltv = 1.337, 
                        median_ltv = 1.337, 
                        outlier_count = 56, 
                        p25_ltv = 1.337, 
                        p75_ltv = 1.337, 
                        persona_name = '', 
                        total_customers = 56, 
                        trimmed_avg_ltv = 1.337, 
                        winsorized_avg_ltv = 1.337, )
                    ],
                error = ''
            )
        else:
            return ReportingDailyMetricsResponse(
        )
        """

    def testReportingDailyMetricsResponse(self):
        """Test ReportingDailyMetricsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
